```{eval-rst}
.. currentmodule:: crowsetta
```

# API Reference

This section documents the 
[API](https://en.wikipedia.org/wiki/API)
of crowsetta.

```{list-table}
:widths: 30 70

* - {ref}`Core <api-core>`
  - The core data types, classes and modules of crowsetta
* - {ref}`Interface <api-interface>`
  - Defines an interface for classes that represent annotation formats
* - {ref}`Formats <api-formats>`
  - Modules with the classes representing annotation formats, 
    and functions for conveniently accessing them.
```

```{toctree}
:hidden: true

core
interface
formats
```
